window.Gleam.initSearch([{"doc":"glee","title":"glee","content":"# glee\n\nGlee is a simple way to parse JSON by taking in JSON and\nreturning a string.\n\nThis is my first package, i&#39;m new to gleam- I&#39;m sure there\nare things I could do better\n\n[![Package Version](https://img.shields.io/hexpm/v/glee)](https://hex.pm/packages/glee)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glee/)\n\n```sh\ngleam add glee@2\n```\n\n## Decoding JSON\n\nGlee also provides functions to decode JSON into values:\n\nGetting a string:\n```gleam\nimport glee\nimport gleam/io\nimport gleam/result\n\npub fn main() {\n  let json = &quot;{\\&quot;name\\&quot;:\\&quot;John\\&quot;,\\&quot;age\\&quot;:30}&quot;\n  let result = glee.parse_json_string(json, &quot;name&quot;)\n  \n  case result {\n    Ok(name) -&gt; io.println(&quot;Name: &quot; &lt;&gt; name)\n    Error(reason) -&gt; io.println(&quot;Error: &quot; &lt;&gt; reason)\n  }\n}\n```\n\nGetting a float:\n```gleam\nimport glee\nimport gleam/io\nimport gleam/float\nimport gleam/result\n\npub fn main() {\n  let json = &quot;{\\&quot;name\\&quot;:\\&quot;John\\&quot;,\\&quot;age\\&quot;:30.4}&quot;\n  let result = glee.parse_json_float(json, &quot;age&quot;)\n  \n  case result {\n    Ok(age) -&gt; io.println(&quot;Age: &quot; &lt;&gt; float.to_string(age))\n    Error(reason) -&gt; io.println(&quot;Error: &quot; &lt;&gt; reason)\n  }\n}\n```\n\nGetting an int:\n```gleam\nimport glee\nimport gleam/io\nimport gleam/int\nimport gleam/result\n\npub fn main() {\n  let json = &quot;{\\&quot;name\\&quot;:\\&quot;John\\&quot;,\\&quot;age\\&quot;:30}&quot;\n  let result = glee.parse_json_int(json, &quot;age&quot;)\n  \n  case result {\n    Ok(age) -&gt; io.println(&quot;Age: &quot; &lt;&gt; int.to_string(age))\n    Error(reason) -&gt; io.println(&quot;Error: &quot; &lt;&gt; reason)\n  }\n}\n```\n\n## Encoding JSON\n\nGlee also provides functions to encode values into JSON:\n\n```gleam\nimport glee\nimport gleam/io\nimport gleam/dict\n\npub fn main() {\n  // Encode simple values\n  let string_json = glee.encode_string(&quot;hello&quot;)  // &quot;hello&quot;\n  let int_json = glee.encode_int(42)  // 42\n  let float_json = glee.encode_float(3.14)  // 3.14\n  let bool_json = glee.encode_bool(True)  // true\n  \n  // Create a simple JSON object\n  let person = glee.create_json_object(&quot;name&quot;, glee.encode_string(&quot;Alice&quot;))\n  io.println(person)  // {&quot;name&quot;:&quot;Alice&quot;}\n  \n  // Create a JSON object from multiple pairs\n  let pairs = [\n    #(&quot;name&quot;, glee.encode_string(&quot;Bob&quot;)),\n    #(&quot;age&quot;, glee.encode_int(30)),\n    #(&quot;active&quot;, glee.encode_bool(True))\n  ]\n  let complex_person = glee.create_json_object_from_pairs(pairs)\n  io.println(complex_person)  // {&quot;name&quot;:&quot;Bob&quot;,&quot;age&quot;:30,&quot;active&quot;:true}\n  \n  // Create a JSON array\n  let values = [\n    glee.encode_string(&quot;apple&quot;),\n    glee.encode_string(&quot;banana&quot;),\n    glee.encode_string(&quot;cherry&quot;)\n  ]\n  let fruits = glee.encode_list(values)\n  io.println(fruits)  // [&quot;apple&quot;,&quot;banana&quot;,&quot;cherry&quot;]\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glee&gt;.\n\n## Development\n\n```sh\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"glee","title":"extract_value_from_json","content":"pub fn extract_value_from_json(\n  json: String,\n  parent: String,\n  key: String,\n) -&gt; String\n Extract a value from a JSON string\n by specifying the parent and key.\nSynonyms:\nglee.extract_value_from_json\nglee extract_value_from_json","url":"glee.html#extract_value_from_json"},{"doc":"glee","title":"parse_json_float","content":"pub fn parse_json_float(\n  json: String,\n  field: String,\n) -&gt; Result(Float, String)\n Parse a JSON string and return\n the float value of a given field.\nSynonyms:\nglee.parse_json_float\nglee parse_json_float","url":"glee.html#parse_json_float"},{"doc":"glee","title":"parse_json_int","content":"pub fn parse_json_int(\n  json: String,\n  field: String,\n) -&gt; Result(Int, String)\n Parse a JSON string and return\n the int value of a given field.\nSynonyms:\nglee.parse_json_int\nglee parse_json_int","url":"glee.html#parse_json_int"},{"doc":"glee","title":"parse_json_string","content":"pub fn parse_json_string(\n  json: String,\n  field: String,\n) -&gt; Result(String, String)\n Parse a JSON string and return\n the string value of a given field.\nSynonyms:\nglee.parse_json_string\nglee parse_json_string","url":"glee.html#parse_json_string"},{"doc":"glee","title":"glee","content":" Glee\n A simple way to parse JSON without\n having to implement the JSON module.\n +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n This is my first time using Gleam, so\n I&#39;m sure there are some things that\n could be done better.","url":"glee.html"}]);